==> consolemock-0.2.1.tgz: package/lib/consolemock.js <==
'use strict';

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var stringifyObject = require('stringify-object');

var LogTypes = {
  log: 'LOG',
  info: 'INFO',
  warn: 'WARN',
  error: 'ERROR'
};

function printLine(line) {
  var key = Object.keys(line)[0];

  var msgs = line[key].map(function (msg) {
    return typeof msg === 'string' ? msg : stringifyObject(msg, { indent: '  ', inlineCharacterLimit: 80 });
  }).join(', ');

  var indentedKey = key.split('').map(function (letter) {
    return letter === '_' ? '  ' : letter;
  }).join('');

  return indentedKey + ' ' + msgs;
}

function makeConsoleMock() {
  var _history = [];
  var groupDepth = 0;

  function prefix(str) {
    var underscores = Array(groupDepth).fill('_').join('');
    return underscores + str;
  }

  function log(logType) {
    for (var _len = arguments.length, msgs = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      msgs[_key - 1] = arguments[_key];
    }

    _history.push(_defineProperty({}, prefix(logType), msgs));
  }

  function group() {
    for (var _len2 = arguments.length, title = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      title[_key2] = arguments[_key2];
    }

    _history.push(_defineProperty({}, prefix('GROUP'), title));
    groupDepth += 1;
  }

  function groupEnd() {
    groupDepth = Math.max(0, groupDepth - 1);
  }

  function printHistory() {
    return _history.reduce(function (printedHistory, line) {
      return [printedHistory, printLine(line)].join('\n');
    }, '');
  }

  return {
    group: group,
    groupEnd: groupEnd,
    printHistory: printHistory,
    history: function history() {
      return _history;
    },
    log: log.bind(null, LogTypes.log),
    info: log.bind(null, LogTypes.info),
    warn: log.bind(null, LogTypes.warn),
    error: log.bind(null, LogTypes.error)
  };
}

module.exports = {
  makeConsoleMock: makeConsoleMock,
  printLine: printLine
};

==> consolemock-0.3.0.tgz: package/lib/consolemock.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var stringifyObject = require('stringify-object');

var LogTypes = {
  log: 'LOG',
  info: 'INFO',
  warn: 'WARN',
  error: 'ERROR'
};

function printLine(line) {
  var key = Object.keys(line)[0];

  var msgs = line[key].map(function (msg) {
    return typeof msg === 'string' ? msg : stringifyObject(msg, { indent: '  ', inlineCharacterLimit: 80 });
  }).join(', ');

  var indentedKey = key.split('').map(function (letter) {
    return letter === '_' ? '  ' : letter;
  }).join('');

  return indentedKey + ' ' + msgs;
}

function makeConsoleMock(nativeConsole) {
  var _history = [];
  var groupDepth = 0;

  function prefix(str) {
    var underscores = Array(groupDepth).fill('_').join('');
    return underscores + str;
  }

  function log(logType) {
    for (var _len = arguments.length, msgs = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      msgs[_key - 1] = arguments[_key];
    }

    _history.push(_defineProperty({}, prefix(logType), msgs));
  }

  function group() {
    for (var _len2 = arguments.length, title = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      title[_key2] = arguments[_key2];
    }

    _history.push(_defineProperty({}, prefix('GROUP'), title));
    groupDepth += 1;
  }

  function groupEnd() {
    groupDepth = Math.max(0, groupDepth - 1);
  }

  function printHistory() {
    return _history.reduce(function (printedHistory, line) {
      return [printedHistory, printLine(line)].join('\n');
    }, '');
  }

  /* istanbul ignore next */
  function print() {
    if ((typeof nativeConsole === 'undefined' ? 'undefined' : _typeof(nativeConsole)) === 'object') {
      nativeConsole.log.apply(nativeConsole, arguments);
    }
  }

  return {
    group: group,
    groupEnd: groupEnd,
    print: print,
    printHistory: printHistory,
    history: function history() {
      return _history;
    },
    log: log.bind(null, LogTypes.log),
    info: log.bind(null, LogTypes.info),
    warn: log.bind(null, LogTypes.warn),
    error: log.bind(null, LogTypes.error)
  };
}

module.exports = {
  makeConsoleMock: makeConsoleMock,
  printLine: printLine
};
